aboutsummaryrefslogtreecommitdiff
path: root/packages/OS400/make-tests.sh
diff options
context:
space:
mode:
Diffstat (limited to 'packages/OS400/make-tests.sh')
-rw-r--r--packages/OS400/make-tests.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/packages/OS400/make-tests.sh b/packages/OS400/make-tests.sh
index 6ef6af914..71943bae4 100644
--- a/packages/OS400/make-tests.sh
+++ b/packages/OS400/make-tests.sh
@@ -17,7 +17,7 @@ cd "${TOPDIR}/tests"
cd libtest
# Get definitions from the Makefile.am file.
# The `sed' statement works as follows:
# _ Join \nl-separated lines.
# _ Retain only lines that begins with "identifier =".
@@ -35,7 +35,7 @@ eval "`sed -e ': begin' \
-e 's/[ ]*=[ ]*/=/' \
-e 's/=\\(.*[^ ]\\)[ ]*$/=\\"\\1\\"/' \
-e 's/\\$(\\([^)]*\\))/${\\1}/g' \
- < Makefile.am`"
+ < Makefile.inc`"
# Compile all programs.
# The list is found in variable "noinst_PROGRAMS"
@@ -17,7 +17,7 @@ cd "${TOPDIR}/tests"
cd libtest
-# Get definitions from the Makefile.am file.
+# Get definitions from the Makefile.inc file.
# The `sed' statement works as follows:
# _ Join \nl-separated lines.